IterableWidgetLeanExtensions<T extends Widget> extension
- on
-
- Iterable<
T>
- Iterable<
Methods
-
separateBy(
Widget separator) → List< Widget> -
Available on Iterable<
returns a List with original items separated by aT> , provided by the IterableWidgetLeanExtensions extensionseparator -
separateByHeight(
num height) → List< Widget> -
Available on Iterable<
returns a List with original items separated by a SizedBox ofT> , provided by the IterableWidgetLeanExtensions extensionheight -
separateByWidth(
num width) → List< Widget> -
Available on Iterable<
returns a List with original items separated by a SizedBox ofT> , provided by the IterableWidgetLeanExtensions extensionwidth