IterableWidgetLeanExtensions<T extends Widget> extension

adds extensions on Iterable<Widget>

on

Methods

separateBy(Widget separator) List<Widget>

Available on Iterable<T>, provided by the IterableWidgetLeanExtensions extension

returns a List with original items separated by a separator
separateByHeight(num height) List<Widget>

Available on Iterable<T>, provided by the IterableWidgetLeanExtensions extension

returns a List with original items separated by a SizedBox of height
separateByWidth(num width) List<Widget>

Available on Iterable<T>, provided by the IterableWidgetLeanExtensions extension

returns a List with original items separated by a SizedBox of width