WidgetsLeanExtensions extension

Adds advanced decorator and constraint extension methods on Widget.

All decorators are prefixed with with to ensure they are easily discoverable via IDE autocompletion (by typing .with).

on

Methods

withMaxSize({num? height, num? width}) Widget

Available on Widget, provided by the WidgetsLeanExtensions extension

Creates a new widget that constrains its child to a maximum size.